/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.config;

import com.ecwid.consul.v1.ConsulClient;
import org.apache.shenyu.admin.config.properties.ConsulProperties;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

public class ConsulSyncConfigurationTest {
    @Test
    public void testConsulClient() {
        ConsulSyncConfiguration consulListener = new ConsulSyncConfiguration();
        ConsulProperties consulProperties = mock(ConsulProperties.class);
        when(consulProperties.getUrl()).thenReturn("http://127.0.0.1:8500");
        assertNotNull(consulListener.consulClient(consulProperties));
    }
    
    @Test
    public void testConsulDataChangedListener() {
        ConsulSyncConfiguration consulListener = new ConsulSyncConfiguration();
        ConsulClient consulClient = mock(ConsulClient.class);
        assertNotNull(consulListener.consulDataChangedListener(consulClient));
    }
    
    @Test
    public void testConsulDataInit() {
        ConsulSyncConfiguration consulListener = new ConsulSyncConfiguration();
        ConsulClient consulClient = mock(ConsulClient.class);
        assertNotNull(consulListener.consulDataChangedInit(consulClient));
    }
}
